Change Log
===========

0.0.3
------
- `helpers.bars_to_pandas()` parses numeric columns as numbers

0.0.2
------
- Added `helpers.bars_to_pandas()` method to convert bars payload to pandas dataframe

0.0.1
------
- Requests wrapper with helper methods
